/**
 * @file
 * Contains the definition of the behavior entityVisibilityPreviewPreviewMessage.
 */

(function (Drupal) {

  'use strict';

  /**
   * Attaches the JS behavior to display preview message.
   */
  Drupal.behaviors.entityVisibilityPreviewPreviewMessage = {

    /**
     * As multiple behaviors can be triggered before the Ajax call returns, we
     * need to store the fact that it is already triggered otherwise the message
     * will be displayed multiple times.
     *
     * @type {Boolean}
     */
    already_called: false,

    attach: function (context, settings) {
      var messages = new Drupal.Message();

      // Check that the message does not already exist.
      var message = messages.select('entity_visibility_preview');
      if (!Drupal.behaviors.entityVisibilityPreviewPreviewMessage.already_called && message === null) {
        Drupal.behaviors.entityVisibilityPreviewPreviewMessage.already_called = true;
        // Get the info using AJAX.
        var xhttp = new XMLHttpRequest();
        xhttp.onreadystatechange = function () {
          if (this.readyState === 4 && this.status === 200 && this.responseText.length !== 0) {
            messages.add(this.responseText, {id: 'entity_visibility_preview'});
          }
        };
        xhttp.open('GET', '/ajax/entity_visibility_preview/preview_message', true);
        xhttp.send();
      }
    }
  };

})(Drupal);
